@@ -28,10 +28,13 @@
 #include <string.h>
 #include <glib.h>
 #include "kz-profile.h"
-#include "bookmarks/kz-bookmark.h"
+#include "bookmarks/kz-root-bookmark.h"
 
 G_BEGIN_DECLS
 
+#define KAZEHAKASE_URI "http://kazehakase.sourceforge.jp/"
+
+
 typedef enum {
 	KZ_UI_LEVEL_INVALID  = 0,
 	KZ_UI_LEVEL_BEGINNER = 1,
@@ -41,33 +44,35 @@ typedef enum {
 	KZ_UI_LEVEL_ALL      = 0xFFFF
 } KzUILevel;
 
+
 KzUILevel    kz_ui_level           (void);
 KzUILevel    kz_ui_level_from_str  (const gchar *level);
 const gchar *kz_ui_level_to_str    (KzUILevel level);
 const gchar *kz_ui_level_to_suffix (KzUILevel level);
 
-extern KzProfile   *kz_global_profile;
-extern KzProfile   *kz_session;
-extern KzProfile   *kz_proxy;
-extern KzBookmark  *kz_bookmark;
-extern KzBookmark  *kz_home;
 
-#define KZ_CONF_GET(s, k, v, t)				\
-	kz_profile_get_value(kz_global_profile,		\
-			     s, k, &(v), sizeof(v),	\
+extern KzProfile      *kz_global_profile;
+extern KzProfile      *kz_session;
+extern KzProfile      *kz_proxy;
+extern KzRootBookmark *kz_bookmarks;
+
+
+#define KZ_CONF_GET(s, k, v, t)					\
+	kz_profile_get_value(kz_global_profile,			\
+			     s, k, &(v), sizeof(v),		\
 			     KZ_PROFILE_VALUE_TYPE_##t)
-#define KZ_CONF_GET_STR(s, k)				\
+#define KZ_CONF_SET(s, k, v, t)					\
+	kz_profile_set_value(kz_global_profile,			\
+			     s, k, &(v), sizeof(v),		\
+			     KZ_PROFILE_VALUE_TYPE_##t)
+#define KZ_CONF_GET_STR(s, k)					\
 	kz_profile_get_string(kz_global_profile, s, k)
-#define KZ_CONF_SET(s, k, v, t)						\
-	((KZ_PROFILE_VALUE_TYPE_##t == KZ_PROFILE_VALUE_TYPE_STRING)	\
-		? kz_profile_set_value(kz_global_profile,		\
-				       s, k,				\
-				       (gchar *)v,			\
-				       strlen((gchar *)v) + 1,		\
-				       KZ_PROFILE_VALUE_TYPE_##t)	\
-		: kz_profile_set_value(kz_global_profile,		\
-				       s, k, &(v), sizeof(v),		\
-				       KZ_PROFILE_VALUE_TYPE_##t))
+#define KZ_CONF_SET_STR(s, k, v)				\
+	 kz_profile_set_value(kz_global_profile,		\
+			      s, k,				\
+			      (gchar *)v,			\
+			      strlen((gchar *)v) + 1,		\
+			      KZ_PROFILE_VALUE_TYPE_STRING)
 
 G_END_DECLS
 
