@@ -50,7 +50,8 @@ struct _KzWindow
 	GtkWidget  *top_vbox;
 
 	/* top of the window */
-	GtkWidget  *bookmarkbar;
+	GtkWidget  *bookmark_bars_area;
+	GList      *bookmark_bars;
 
 	/* middle of the window */
 	GtkWidget  *pane;
